==> haskell-call-stack-0.2.0-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-call-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 call-stack
version:              0.2.0
visibility:           public
id:                   call-stack-0.2.0-BP8110dRMpq7CTXEnOdsEd
key:                  call-stack-0.2.0-BP8110dRMpq7CTXEnOdsEd
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/call-stack#readme
synopsis:             Use GHC call-stacks in a backward compatible way
category:             Data
abi:                  351e44b300ff384f5881c51d0cb277bd
exposed:              True
exposed-modules:      Data.CallStack
hidden-modules:       Data.SrcLoc Paths_call_stack
import-dirs:          /usr/lib/ghc-8.10.1/site-local/call-stack-0.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/call-stack-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/call-stack-0.2.0
hs-libraries:         HScall-stack-0.2.0-BP8110dRMpq7CTXEnOdsEd
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-call-stack/html/call-stack.haddock
haddock-html:         /usr/share/doc/haskell-call-stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-call-stack-0.2.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-call-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 call-stack
version:              0.2.0
visibility:           public
id:                   call-stack-0.2.0-8UgjMLKDWGSGkXDMjX7som
key:                  call-stack-0.2.0-8UgjMLKDWGSGkXDMjX7som
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/call-stack#readme
synopsis:             Use GHC call-stacks in a backward compatible way
category:             Data
abi:                  9adaa6f1412ef55795b769dba23a64b5
exposed:              True
exposed-modules:      Data.CallStack
hidden-modules:       Data.SrcLoc Paths_call_stack
import-dirs:          /usr/lib/ghc-8.10.1/site-local/call-stack-0.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/call-stack-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/call-stack-0.2.0
hs-libraries:         HScall-stack-0.2.0-8UgjMLKDWGSGkXDMjX7som
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-call-stack/html/call-stack.haddock
haddock-html:         /usr/share/doc/haskell-call-stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
